nbxmpp.stringprepare.Profile

Package nbxmpp :: Module stringprepare :: Class Profile |
[hide private]
[frames] | no frames]

# Class Profile

source code

Instance Methods | [hide private]
__init__(self, mappings=`[``]`, normalize=True, prohibiteds=`[``]`, check_unassigneds=True, check_bidi=True) | source code
prepare(self, string) | source code
map(self, string) | source code
check_prohibiteds(self, string) | source code
check_unassigneds(self, string) | source code
check_bidirectionals(self, string) | source code

Method Details | [hide private]

### __init__(self, mappings=`[``]`, normalize=True, prohibiteds=`[``]`, check_unassigneds=True, check_bidi=True) (Constructor) | source code

### prepare(self, string) | source code

### map(self, string) | source code

### check_prohibiteds(self, string) | source code

### check_unassigneds(self, string) | source code

### check_bidirectionals(self, string) | source code